#!/bin/bash
SELF_DIR=`dirname $0`
cd ${SELF_DIR}
export LANG="ja_JP.UTF-8" && python ./install.py
mv Makefile.base Makefile
